==> haskell-hls-change-type-signature-plugin-2.1.0.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-change-type-signature-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-change-type-signature-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-change-type-signature-plugin-2.1.0.0-3nLjBD6hwuqEXLAoKVc2np

key:
    hls-change-type-signature-plugin-2.1.0.0-3nLjBD6hwuqEXLAoKVc2np

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:             Change a declarations type signature with a Code Action
description:
    Please see the README on GitHub at <https://github.com/haskell/plugins/hls-change-type-signature-plugin/README.md>

category:             Development
abi:                  f4fb358ed94736c18719f83efd9f393d
exposed:              True
exposed-modules:      Ide.Plugin.ChangeTypeSignature
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-change-type-signature-plugin
hs-libraries:
    HShls-change-type-signature-plugin-2.1.0.0-3nLjBD6hwuqEXLAoKVc2np

depends:
    base-4.17.2.1 containers-0.6.7
    ghcide-2.1.0.0-C3k2JoHzVFoJNRZAKgVqZR
    hls-plugin-api-2.1.0.0-I8ncicijyZ5KNllb3jOSNb
    lsp-types-2.0.1.0-1uiCr1mSqedEpljvVeyw37
    regex-tdfa-1.3.2.4-AG3wQnDWHjR8IyIVdzEE1S
    syb-0.7.2.4-8acugsE4IM46MgrbkheGRX text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-3iRUctzIz2JCUYhLp7SKku

haddock-interfaces:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html/hls-change-type-signature-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-change-type-signature-plugin-2.1.0.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-change-type-signature-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-change-type-signature-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-change-type-signature-plugin-2.1.0.0-G4eK9NycaylJh2amUWDTaI

key:
    hls-change-type-signature-plugin-2.1.0.0-G4eK9NycaylJh2amUWDTaI

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:             Change a declarations type signature with a Code Action
description:
    Please see the README on GitHub at <https://github.com/haskell/plugins/hls-change-type-signature-plugin/README.md>

category:             Development
abi:                  5394f32c73099633a7bfa649512cb450
exposed:              True
exposed-modules:      Ide.Plugin.ChangeTypeSignature
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-change-type-signature-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-change-type-signature-plugin
hs-libraries:
    HShls-change-type-signature-plugin-2.1.0.0-G4eK9NycaylJh2amUWDTaI

depends:
    base-4.17.2.1 containers-0.6.7
    ghcide-2.1.0.0-1fttxqdGDZX5IFxBz1Sgdg
    hls-plugin-api-2.1.0.0-6PdqQKQ4gksDI17icI0y9H
    lsp-types-2.0.1.0-1uiCr1mSqedEpljvVeyw37
    regex-tdfa-1.3.2.4-AG3wQnDWHjR8IyIVdzEE1S
    syb-0.7.2.4-8acugsE4IM46MgrbkheGRX text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-3iRUctzIz2JCUYhLp7SKku

haddock-interfaces:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html/hls-change-type-signature-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-change-type-signature-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
